@@ -342,20 +342,10 @@ impl<S: std::fmt::Debug + Clone + Default + PartialEq + Eq + 'static> std::fmt::
 impl<S: std::fmt::Debug + Clone + Default + PartialEq + Eq> Store<S> {
     /// Create a new Store.
     pub fn new(
-        initializer: impl Fn(&mut S) + 'static,
         reducer: impl Fn(&Action, &mut S) + 'static,
         middlewares: Vec<Box<dyn Middleware<S>>>,
     ) -> Self {
-        let mut state = Default::default();
-        print_perf!(
-            {
-                initializer(&mut state);
-                for m in &middlewares {
-                    m.as_ref().post_reduce(&Action::new(crate::INIT.into(), None), &mut state);
-                }
-            };
-            "Initialization phase"
-        );
+        let state = Default::default();
         Store {
             state: Arc::new(Mutex::new(state)),
             reducer: Arc::new(Mutex::new(Box::new(reducer))),
@@ -631,11 +621,13 @@ macro_rules! store {
         /// - reducer: Handle actions and mutate the state
         /// - middlewares: Pre- and post-reduce handlers
         pub fn init_store(
-            initializer: impl Fn(&mut $state) + 'static,
             reducer: impl Fn(&gstore::Action, &mut $state) + 'static,
             middlewares: Vec<Box<dyn gstore::Middleware<$state>>>,
         ) {
-            unsafe { STORE = Some(Store::new(initializer, reducer, middlewares)) }
+            unsafe {
+                STORE = Some(Store::new(reducer, middlewares));
+                STORE.as_ref().unwrap().dispatch(gstore::INIT.into(), None);
+            }
         }
 
         /// Get a static reference to the store
